summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
authorcgd <cgd@NetBSD.org>1993-12-10 10:57:40 +0000
committercgd <cgd@NetBSD.org>1993-12-10 10:57:40 +0000
commit0e5dbe1a22bcdceeb388a9933e632d17a38a5e8a (patch)
treed589c7d2838d0e31fbe164a753ea983d533cb9c0 /sys
parent1da7a80f7e972799af5e6fcf4c79bb17a71d9851 (diff)
IF_LLC0 -> IF_LINK0
Diffstat (limited to 'sys')
-rw-r--r--sys/arch/i386/isa/if_ec.c6
-rw-r--r--sys/arch/i386/isa/if_ed.c4
-rw-r--r--sys/dev/isa/if_ed.c4
3 files changed, 7 insertions, 7 deletions
diff --git a/sys/arch/i386/isa/if_ed.c b/sys/arch/i386/isa/if_ed.c
index 4f2788fc199..80748d48c21 100644
--- a/sys/arch/i386/isa/if_ed.c
+++ b/sys/arch/i386/isa/if_ed.c
@@ -20,7 +20,7 @@
*/
/*
- * $Id: if_ed.c,v 1.11 1993/12/10 05:37:33 hpeyerl Exp $
+ * $Id: if_ed.c,v 1.12 1993/12/10 10:57:47 cgd Exp $
*/
/*
@@ -129,7 +129,7 @@
/* For backwards compatibility */
#ifndef IFF_ALTPHYS
-#define IFF_ALTPHYS IFF_LLC0
+#define IFF_ALTPHYS IFF_LINK0
#endif
/*
diff --git a/sys/dev/isa/if_ed.c b/sys/dev/isa/if_ed.c
index 4f2788fc199..80748d48c21 100644
--- a/sys/dev/isa/if_ed.c
+++ b/sys/dev/isa/if_ed.c
@@ -20,7 +20,7 @@
*/
/*
- * $Id: if_ed.c,v 1.11 1993/12/10 05:37:33 hpeyerl Exp $
+ * $Id: if_ed.c,v 1.12 1993/12/10 10:57:47 cgd Exp $
*/
/*
@@ -129,7 +129,7 @@
/* For backwards compatibility */
#ifndef IFF_ALTPHYS
-#define IFF_ALTPHYS IFF_LLC0
+#define IFF_ALTPHYS IFF_LINK0
#endif
/*
diff --git a/sys/arch/i386/isa/if_ec.c b/sys/arch/i386/isa/if_ec.c
index 3b605b94cf1..cb5b5d98458 100644
--- a/sys/arch/i386/isa/if_ec.c
+++ b/sys/arch/i386/isa/if_ec.c
@@ -33,7 +33,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: if_ec.c,v 1.10 1993/06/14 16:45:25 mycroft Exp $
+ * $Id: if_ec.c,v 1.11 1993/12/10 10:57:40 cgd Exp $
*/
/*
@@ -265,10 +265,10 @@ int unit;
return;
/*
* select thick (e.g. AUI connector) if LLC0 bit is set
*/
outb(sc->ec_io_ctl_addr + E33G_CNTRL,
- (ifp->if_flags & IFF_LLC0) ? 0 : ECNTRL_ONBOARD);
+ (ifp->if_flags & IFF_LINK0) ? 0 : ECNTRL_ONBOARD);
/*
* Set up the 8390 chip.
@@ -265,10 +265,10 @@ int unit;
return;
/*
- * select thick (e.g. AUI connector) if LLC0 bit is set
+ * select thick (e.g. AUI connector) if LINK0 bit is set
*/
outb(sc->ec_io_ctl_addr + E33G_CNTRL,